@@ -121,7 +121,7 @@ use strict;
 use POSIX qw/locale_h/;
 use locale;
 use vars qw ($VERSION @ISA @REGEXS);
-$VERSION = 0.88;
+$VERSION = 0.99;
 
 use overload (
     '""'       => \&stringify,
@@ -129,13 +129,22 @@ use overload (
     'cmp'      => \&vcmp,
     '<=>'      => \&vcmp,
     'bool'     => \&vbool,
-    'nomethod' => \&vnoop,
+    '+'        => \&vnoop,
+    '-'        => \&vnoop,
+    '*'        => \&vnoop,
+    '/'        => \&vnoop,
+    '+='        => \&vnoop,
+    '-='        => \&vnoop,
+    '*='        => \&vnoop,
+    '/='        => \&vnoop,
+    'abs'      => \&vnoop,
 );
 
 eval "use warnings";
 if ($@) {
     eval '
-	package warnings;
+	package
+	warnings;
 	sub enabled {return $^W;}
 	1;
     ';
@@ -272,6 +281,11 @@ dotted_decimal_version:
 	    }
 	}
 
+	# and we never support negative version numbers
+	if ($d eq '-') {
+	    return BADVERSION($s,$errstr,"Invalid version format (negative version number)");
+	}
+
 	# consume all of the integer part
 	while (isDIGIT($d)) {
 	    $d++;
@@ -718,7 +732,7 @@ sub vcmp
     }
     unless (_verify($right)) {
 	require Carp;
-	Carp::croak("Invalid version object");
+	Carp::croak("Invalid version format");
     }
     my $l = $#{$left->{version}};
     my $r = $#{$right->{version}};
@@ -794,8 +808,8 @@ sub qv {
 
     $value = _un_vstring($value);
     $value = 'v'.$value unless $value =~ /(^v|\d+\.\d+\.\d)/;
-    my $version = $class->new($value);
-    return $version;
+    my $obj = version->new($value);
+    return bless $obj, $class;
 }
 
 *declare = \&qv;
